.. msprime documentation master file, created by
   sphinx-quickstart on Mon Jun  1 16:13:14 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to msprime's documentation!
===================================

This is the documentation for ``msprime``, a reimplementation of Hudson's
classical :command:`ms` simulator.

If you are looking for help on a specific issue or would like to ask a
question to fellow ``msprime`` users, please send an email to the
`mailing list <https://groups.google.com/group/msprime-users>`_. By asking
questions on the mailing list, you can help to build a searchable knowledge
base.

Contents:
=========

.. toctree::
   :maxdepth: 2

   introduction
   installation
   tutorial
   api
   cli
   development
   CITATION

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

